/* This file is part of the db4o object database http://www.db4o.com

Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com

db4o is free software; you can redistribute it and/or modify it under
the terms of version 3 of the GNU General Public License as published
by the Free Software Foundation.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see http://www.gnu.org/licenses/. */
using System;
using Db4oUnit.Extensions;
using Db4objects.Db4o.Tests.Common.Staging;

namespace Db4objects.Db4o.Tests.Common.Staging
{
	public class AllTests : ComposibleTestSuite
	{
		public static void Main(string[] args)
		{
			new Db4objects.Db4o.Tests.Common.Staging.AllTests().RunSolo();
		}

		protected override Type[] TestCases()
		{
			return ComposeTests(new Type[] { typeof(ActivateDepthTestCase), typeof(InterfaceQueryTestCase
				), typeof(GenericClassWithExistingSuperClassTestCase), typeof(LazyQueryDeleteTestCase
				), typeof(OldVersionReflectFieldAfterRefactorTestCase), typeof(RemovedFieldDefragmentTestCase
				), typeof(StoredClassUnknownClassQueryTestCase), typeof(UntypedFieldSortingTestCase
				) });
		}

		// COR-1131
		// COR-1959
		// COR-1937
		// COR-1542
		#if !SILVERLIGHT
		protected override Type[] ComposeWith()
		{
			return new Type[] { typeof(ClientServerPingTestCase), typeof(DeepPrefetchingCacheConcurrencyTestCase
				), typeof(OwnCommitCallbackFlaggedEmbeddedTestSuite), typeof(PingTestCase), typeof(
				TAUnavailableClassAtServer) };
		}
		#endif // !SILVERLIGHT
		// COR-1762
		// COR-1964
		//COR-1987
	}
}
